spawn

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 23, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Terminal

type Terminal interface {
	Name() string
	OpenTab(dir string, shellCmd string, title string) error
}

Terminal represents a detected terminal emulator that can open new tabs/windows.

func Detect

func Detect() Terminal

Detect returns the best Terminal implementation for the current environment.

func DetectWithOverride

func DetectWithOverride(t Terminal) Terminal

DetectWithOverride returns a Terminal, allowing DI for testing.

Jump to