Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Terminal ¶
Terminal represents a detected terminal emulator that can open new tabs/windows.
func Detect ¶
func Detect() Terminal
Detect returns the best Terminal implementation for the current environment.
func DetectWithOverride ¶
DetectWithOverride returns a Terminal, allowing DI for testing.
Click to show internal directories.
Click to hide internal directories.